"""
Lists or enumerations—for example, a list of cuisines or music genres, etc.

https://schema.org/Enumeration
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class EnumerationInheritedProperties(TypedDict):
    """Lists or enumerations—for example, a list of cuisines or music genres, etc.

    References:
        https://schema.org/Enumeration
    Note:
        Model Depth 3
    Attributes:
    """

    


class EnumerationProperties(TypedDict):
    """Lists or enumerations—for example, a list of cuisines or music genres, etc.

    References:
        https://schema.org/Enumeration
    Note:
        Model Depth 3
    Attributes:
        supersededBy: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Relates a term (i.e. a property, class or enumeration) to one that supersedes it.
    """

    supersededBy: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class AllProperties(EnumerationInheritedProperties , EnumerationProperties, TypedDict):
    pass


class EnumerationBaseModel(SchemaOrgBase):
    id_ : Optional[Any] = Field(default="Enumeration",alias='@id')
    context_ : Optional[Any] = Field(default=None,alias='@context')
    graph_ : Optional[Any] = Field(default=None,alias='@graph')

    class Config:
        
        fields = {'supersededBy': {'exclude': True}}
        


def create_schema_org_model(type_: Union[EnumerationProperties, EnumerationInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "Enumeration"
    return model
    

Enumeration = create_schema_org_model()


def create_enumeration_model(model: AllProperties):
    _type =  AllProperties.copy()
    for k in model.keys():
        if k not in _type.__annotations__:
            del _type.__annotations__[k]
    return create_schema_org_model(type_=_type)


def schema_json(model: AllProperties):
    pydantic_type =  create_enumeration_model(model=model)
    return pydantic_type(model).schema_json()


