"""
A description of costs to the patient under a given network or formulary.

https://schema.org/HealthPlanCostSharingSpecification
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class HealthPlanCostSharingSpecificationInheritedProperties(TypedDict):
    """A description of costs to the patient under a given network or formulary.

    References:
        https://schema.org/HealthPlanCostSharingSpecification
    Note:
        Model Depth 3
    Attributes:
    """

    


class HealthPlanCostSharingSpecificationProperties(TypedDict):
    """A description of costs to the patient under a given network or formulary.

    References:
        https://schema.org/HealthPlanCostSharingSpecification
    Note:
        Model Depth 3
    Attributes:
        healthPlanCoinsuranceRate: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): The rate of coinsurance expressed as a number between 0.0 and 1.0.
        healthPlanCopayOption: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Whether the copay is before or after deductible, etc. TODO: Is this a closed set?
        healthPlanPharmacyCategory: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The category or type of pharmacy associated with this cost sharing.
        healthPlanCopay: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The copay amount.
        healthPlanCoinsuranceOption: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed set?
    """

    healthPlanCoinsuranceRate: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    healthPlanCopayOption: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    healthPlanPharmacyCategory: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    healthPlanCopay: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    healthPlanCoinsuranceOption: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class AllProperties(HealthPlanCostSharingSpecificationInheritedProperties , HealthPlanCostSharingSpecificationProperties, TypedDict):
    pass


class HealthPlanCostSharingSpecificationBaseModel(SchemaOrgBase):
    id_ : Optional[Any] = Field(default="HealthPlanCostSharingSpecification",alias='@id')
    context_ : Optional[Any] = Field(default=None,alias='@context')
    graph_ : Optional[Any] = Field(default=None,alias='@graph')

    class Config:
        
        fields = {'healthPlanCoinsuranceRate': {'exclude': True}}
        fields = {'healthPlanCopayOption': {'exclude': True}}
        fields = {'healthPlanPharmacyCategory': {'exclude': True}}
        fields = {'healthPlanCopay': {'exclude': True}}
        fields = {'healthPlanCoinsuranceOption': {'exclude': True}}
        


def create_schema_org_model(type_: Union[HealthPlanCostSharingSpecificationProperties, HealthPlanCostSharingSpecificationInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "HealthPlanCostSharingSpecification"
    return model
    

HealthPlanCostSharingSpecification = create_schema_org_model()


def create_healthplancostsharingspecification_model(model: AllProperties):
    _type =  AllProperties.copy()
    for k in model.keys():
        if k not in _type.__annotations__:
            del _type.__annotations__[k]
    return create_schema_org_model(type_=_type)


def schema_json(model: AllProperties):
    pydantic_type =  create_healthplancostsharingspecification_model(model=model)
    return pydantic_type(model).schema_json()


