"""
An [[OpinionNewsArticle]] is a [[NewsArticle]] that primarily expresses opinions rather than journalistic reporting of news and events. For example, a [[NewsArticle]] consisting of a column or [[Blog]]/[[BlogPosting]] entry in the Opinions section of a news publication. 

https://schema.org/OpinionNewsArticle
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class OpinionNewsArticleInheritedProperties(TypedDict):
    """An [[OpinionNewsArticle]] is a [[NewsArticle]] that primarily expresses opinions rather than journalistic reporting of news and events. For example, a [[NewsArticle]] consisting of a column or [[Blog]]/[[BlogPosting]] entry in the Opinions section of a news publication. 

    References:
        https://schema.org/OpinionNewsArticle
    Note:
        Model Depth 5
    Attributes:
        printColumn: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The number of the column in which the NewsArticle appears in the print edition.
        printEdition: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The edition of the print product in which the NewsArticle appears.
        printSection: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): If this NewsArticle appears in print, this field indicates the print section in which the article appeared.
        printPage: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): If this NewsArticle appears in print, this field indicates the name of the page on which the article is found. Please note that this field is intended for the exact page name (e.g. A5, B18).
        dateline: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A [dateline](https://en.wikipedia.org/wiki/Dateline) is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted. Sometimes only a placename is provided.Structured representations of dateline-related information can also be expressed more explicitly using [[locationCreated]] (which represents where a work was created, e.g. where a news report was written).  For location depicted or described in the content, use [[contentLocation]].Dateline summaries are oriented more towards human readers than towards automated processing, and can vary substantially. Some examples: "BEIRUT, Lebanon, June 2.", "Paris, France", "December 19, 2017 11:43AM Reporting from Washington", "Beijing/Moscow", "QUEZON CITY, Philippines".      
    """

    printColumn: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    printEdition: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    printSection: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    printPage: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    dateline: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class OpinionNewsArticleProperties(TypedDict):
    """An [[OpinionNewsArticle]] is a [[NewsArticle]] that primarily expresses opinions rather than journalistic reporting of news and events. For example, a [[NewsArticle]] consisting of a column or [[Blog]]/[[BlogPosting]] entry in the Opinions section of a news publication. 

    References:
        https://schema.org/OpinionNewsArticle
    Note:
        Model Depth 5
    Attributes:
    """

    


class AllProperties(OpinionNewsArticleInheritedProperties , OpinionNewsArticleProperties, TypedDict):
    pass


class OpinionNewsArticleBaseModel(SchemaOrgBase):
    id_ : Optional[Any] = Field(default="OpinionNewsArticle",alias='@id')
    context_ : Optional[Any] = Field(default=None,alias='@context')
    graph_ : Optional[Any] = Field(default=None,alias='@graph')

    class Config:
        
        fields = {'printColumn': {'exclude': True}}
        fields = {'printEdition': {'exclude': True}}
        fields = {'printSection': {'exclude': True}}
        fields = {'printPage': {'exclude': True}}
        fields = {'dateline': {'exclude': True}}
        


def create_schema_org_model(type_: Union[OpinionNewsArticleProperties, OpinionNewsArticleInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "OpinionNewsArticle"
    return model
    

OpinionNewsArticle = create_schema_org_model()


def create_opinionnewsarticle_model(model: AllProperties):
    _type =  AllProperties.copy()
    for k in model.keys():
        if k not in _type.__annotations__:
            del _type.__annotations__[k]
    return create_schema_org_model(type_=_type)


def schema_json(model: AllProperties):
    pydantic_type =  create_opinionnewsarticle_model(model=model)
    return pydantic_type(model).schema_json()


