"""
A service provided by an organization, e.g. delivery service, print services, etc.

https://schema.org/Service
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class ServiceInheritedProperties(TypedDict):
    """A service provided by an organization, e.g. delivery service, print services, etc.

    References:
        https://schema.org/Service
    Note:
        Model Depth 3
    Attributes:
    """

    


class ServiceProperties(TypedDict):
    """A service provided by an organization, e.g. delivery service, print services, etc.

    References:
        https://schema.org/Service
    Note:
        Model Depth 3
    Attributes:
        serviceArea: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The geographic area where the service is provided.
        broker: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An entity that arranges for an exchange between a buyer and a seller.  In most cases a broker never acquires or releases ownership of a product or service involved in an exchange.  If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.
        provider: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
        areaServed: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The geographic area where a service or offered item is provided.
        slogan: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A slogan or motto associated with the item.
        award: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An award won by or for this item.
        termsOfService: (Optional[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]): Human-readable terms of service documentation.
        review: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A review of the item.
        availableChannel: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).
        isRelatedTo: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A pointer to another, somehow related product (or multiple products).
        serviceAudience: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The audience eligible for this service.
        isSimilarTo: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A pointer to another, functionally similar product (or multiple products).
        audience: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An intended audience, i.e. a group for whom something was created.
        logo: (Optional[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]): An associated logo.
        providerMobility: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Indicates the mobility of a provided service (e.g. 'static', 'dynamic').
        hoursAvailable: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The hours during which this service or contact is available.
        brand: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
        serviceOutput: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The tangible thing generated by the service, e.g. a passport, permit, etc.
        produces: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The tangible thing generated by the service, e.g. a passport, permit, etc.
        hasOfferCatalog: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Indicates an OfferCatalog listing for this Organization, Person, or Service.
        category: (Optional[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]): A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
        aggregateRating: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The overall rating, based on a collection of reviews or ratings, of the item.
        serviceType: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The type of service being offered, e.g. veterans' benefits, emergency relief, etc.
        offers: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.      
    """

    serviceArea: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    broker: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    provider: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    areaServed: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    slogan: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    award: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    termsOfService: NotRequired[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]
    review: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    availableChannel: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    isRelatedTo: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    serviceAudience: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    isSimilarTo: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    audience: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    logo: NotRequired[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]
    providerMobility: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    hoursAvailable: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    brand: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    serviceOutput: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    produces: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    hasOfferCatalog: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    category: NotRequired[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]
    aggregateRating: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    serviceType: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    offers: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class AllProperties(ServiceInheritedProperties , ServiceProperties, TypedDict):
    pass


class ServiceBaseModel(SchemaOrgBase):
    id_ : Optional[Any] = Field(default="Service",alias='@id')
    context_ : Optional[Any] = Field(default=None,alias='@context')
    graph_ : Optional[Any] = Field(default=None,alias='@graph')

    class Config:
        
        fields = {'serviceArea': {'exclude': True}}
        fields = {'broker': {'exclude': True}}
        fields = {'provider': {'exclude': True}}
        fields = {'areaServed': {'exclude': True}}
        fields = {'slogan': {'exclude': True}}
        fields = {'award': {'exclude': True}}
        fields = {'termsOfService': {'exclude': True}}
        fields = {'review': {'exclude': True}}
        fields = {'availableChannel': {'exclude': True}}
        fields = {'isRelatedTo': {'exclude': True}}
        fields = {'serviceAudience': {'exclude': True}}
        fields = {'isSimilarTo': {'exclude': True}}
        fields = {'audience': {'exclude': True}}
        fields = {'logo': {'exclude': True}}
        fields = {'providerMobility': {'exclude': True}}
        fields = {'hoursAvailable': {'exclude': True}}
        fields = {'brand': {'exclude': True}}
        fields = {'serviceOutput': {'exclude': True}}
        fields = {'produces': {'exclude': True}}
        fields = {'hasOfferCatalog': {'exclude': True}}
        fields = {'category': {'exclude': True}}
        fields = {'aggregateRating': {'exclude': True}}
        fields = {'serviceType': {'exclude': True}}
        fields = {'offers': {'exclude': True}}
        


def create_schema_org_model(type_: Union[ServiceProperties, ServiceInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "Service"
    return model
    

Service = create_schema_org_model()


def create_service_model(model: AllProperties):
    _type =  AllProperties.copy()
    for k in model.keys():
        if k not in _type.__annotations__:
            del _type.__annotations__[k]
    return create_schema_org_model(type_=_type)


def schema_json(model: AllProperties):
    pydantic_type =  create_service_model(model=model)
    return pydantic_type(model).schema_json()


